Package: ABACUS
Title: Apps Based Activities for Communicating and Understanding
        Statistics
Version: 1.0.0
Author: Mintu Nath [aut, cre]
Maintainer: Mintu Nath <dr.m.nath@gmail.com>
Description: A set of Shiny apps for effective communication and understanding in statistics. The current version includes properties of normal distribution, properties of sampling distribution, one-sample z and t tests, two samples independent (unpaired) t test and analysis of variance.
Depends: R (>= 3.1.0)
Imports: ggplot2 (>= 3.1.0), shiny (>= 1.3.1),
Suggests: rmarkdown (>= 1.13), knitr (>= 1.22)
License: GPL-3
URL: https://shiny.abdn.ac.uk/Stats/apps/
VignetteBuilder: knitr
RoxygenNote: 6.1.1.9000
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2019-09-12 14:16:35 UTC; s02mn9
Repository: CRAN
LazyData: true
Date/Publication: 2019-09-20 07:40:06 UTC
Built: R 4.6.0; ; 2026-04-26 15:50:05 UTC; unix
