# Generated by roxygen2: do not edit by hand

export(shiny_anova)
export(shiny_dnorm)
export(shiny_dnorm_dt)
export(shiny_onesampt)
export(shiny_onesampz)
export(shiny_sampling)
export(shiny_twosampt)
import(ggplot2)
import(shiny)
