This directory contains a presentation we did using the Abacus for our final
graduation project. Even though the presentation is in Portuguese, the file
abacus-presentation.tcl implements a generic slide viewer in 'Abacus Tcl'
that loads a script 'slides.tcl' with a list of slides that include text,
images or Abacus scripts. 

It serves as an example of what you can do with Tcl inside Abacus, mainly in
the slides that are marcos running inside the Abacus where you can see how
to use our exported functions.
