# Contributing

- Please open an issue for bugs or ideas. Include steps or context if you can.
- Feel free to submit a PR if you already have a fix—just run `cargo fmt`, `cargo clippy`, and `cargo test` first.
- Not sure about the direction? Start an issue and we can chat. I'm happy to implement features on your behalf.
