# Security Policy

## Supported Versions

Only the latest released minor version of abacus is supported.

## Reporting a Vulnerability

If you believe you have found a security vulnerability, please DO NOT disclose it publicly until we’ve had a chance to fix it.

Please don’t report security vulnerabilities via GitHub issues, instead [report them privately](https://docs.github.com/en/code-security/security-advisories/guidance-on-reporting-and-writing-information-about-vulnerabilities/privately-reporting-a-security-vulnerability) via the [Security Advisories](https://github.com/cyanboy/abacus/security/advisories/new) page.
